@@ -1,8 +1,7 @@
 import datetime
 
 from django import template
-
-from commons.python import formatter
+from commons.python import formatter, utils
 
 register = template.Library()
 
@@ -25,3 +24,13 @@ def date_format(date: datetime):
 @register.filter(name='datetimef')
 def date_time_format(date_time: datetime):
     return formatter.date_time(date_time)
+
+
+@register.filter(name='true_if_none')
+def true_if_none(value):
+    return utils.true_if_none(value)
+
+
+@register.filter(name='to_boolean')
+def to_boolean(value):
+    return utils.to_boolean(value)
